@@ -111,11 +111,8 @@ def evaluate_core(
         if not isinstance(metric_items, list):
             metric_items = [metric_items]
     if areas is not None:
-        assert (
-            len(areas) == 3
-        ), "3 integers should be specified as areas, \
-            representing 3 area regions"
-
+        if len(areas) != 3:
+            raise ValueError("3 integers should be specified as areas, representing 3 area regions")
     eval_results = OrderedDict()
     cocoGt = COCO(dataset_path)
     cat_ids = list(cocoGt.cats.keys())
@@ -206,8 +203,10 @@ def evaluate_core(
             # from https://github.com/facebookresearch/detectron2/
             precisions = cocoEval.eval["precision"]
             # precision: (iou, recall, cls, area range, max dets)
-            assert len(cat_ids) == precisions.shape[2]
-
+            if len(cat_ids) != precisions.shape[2]:
+                raise ValueError(
+                    f"The number of categories {len(cat_ids)} is not equal to the number of precisions {precisions.shape[2]}"
+                )
             max_cat_name_len = 0
             for idx, catId in enumerate(cat_ids):
                 nm = cocoGt.loadCats(catId)[0]
